#' @title Clause-ordering data
#' @name clauseorders
#' @description This data set contains corpus-based clause-ordering data for 403 complex sentences and several potential predictors.
#' @docType data
#'
#' @format A data frame with 403 observations/cases and 6 variables:
#' \describe{
#'   \item{CASE}{Numeric: a unique identifier for each case, in the interval [2, 5053]}
#'   \item{ORDER}{Factor: the clause order a speaker chose for a complex sentence in corpus data, with levels "mc-sc", "sc-mc"}
#'   \item{SCTYPE}{Factor: the kind of subordinate clause involved in the sentence, with levels "caus", "temp"}
#'   \item{CONJ}{Factor: the subordinate conjunction involved in the sentence, with levels "als/when", "bevor/before", "nachdem/after", "weil/because"}
#'   \item{LENMC}{Numeric: the length of the main clause in words, in the interval [2, 31]}
#'   \item{LENSC}{Numeric: the length of the subordinate clause in words, in the interval [2, 36]}
#'   \item{LENDIFF}{Numeric: the length difference LENMC minus LENSC, in the interval [-32, 25]}
#'   \item{MORETHAN2CL}{Factor: whether there is more material in the sentence than just the main clause and the subordinate clause, with levels "no", "yes"}
#' }
#'
#' @details This is the data set used in SFLWR 3, section 5.3
#' @source NA
#' @references \url{https://www.stgries.info/research/sflwr/sflwr.html}
read.delim("clauseorders.csv", stringsAsFactors=TRUE)
