#' @title Subject realization data for Japanese conversation
#' @name subjreal
#' @description This data set contains corpus-based subject realization data with two linguistic predictors and a predictor whether speakers are native speakers or learners.
#' @docType data
#'
#' @format A data frame with 14765 observations/cases and 6 variables:
#' \describe{
#'   \item{CASE}{Numeric: a unique identifier for each case, in the interval [2, 15265]}
#'   \item{SPRK}{Factor: whether the speaker is a native Japanese speakers of Japanese or a non-native speaker, with levels "njs", "nns"}
#'   \item{SPEAKERID}{Factor: a code for the speaker who produced a clause, with 24 levels}
#'   \item{SUBJREAL}{Factor: the response variable encoding whether a subject was produced in a clause or not, with levels "no", "yes"}
#'   \item{CONTRAST}{Factor: whether the referent of the subject would be contrastive or not, with levels "no", "yes"}
#'   \item{GIVENNESS}{Numeric: a predictor encoding how discourse-given the referent of the subject would be, in the interval [0, 10]}
#' }
#'
#' @details This is part of the data set used in Gries, Stefan Th. & Allison S. Adelman. 2014. Subject realization in Japanese conversation by native and non-native speakers: [...]. In Jesús Romero-Trillo (ed.), *Yearbook of Corpus Linguistics and Pragmatics 2014: New empirical and theoretical paradigms*, 35-54. Cham: Springer.
#' @source see Gries & Adelman (2014)
#' @references \url{https://www.stgries.info/research/2014_STG-ASA_MuPDAR-MEM-JapSubjRealiz_YbCorpLingPragm.pdf}
read.delim("subjreal.csv", stringsAsFactors=TRUE)
