#' @title Third person singular over time
#' @name thirdpers
#' @description This data set is concerned with the third-person singular suffix in diachronic English, specifically whether speakers wrote the old form (*giveth*) or the newer and now contemporary form (*gives*). The question is what made letter writers choose which form.
#' @docType data
#'
#' @format A data frame with 4143 observations/cases and 8 variables:
#' \describe{
#'   \item{VARIANT}{Factor: the third person singular form chosen by a speaker, with levels "th", "s"}
#'   \item{AUTH_GEND}{Factor: the sex of the writer of the letter, with levels "female", "male"}
#'   \item{REC_SAME_GEND}{Factor: whether the recipient was of the same sex, with levels "no", "yes"}
#'   \item{CLOSE_FAM}{Factor: whether the recipient was a close family member, with levels "no", "yes"}
#'   \item{VNCPERIOD}{Factor: the time period (during 1400-1700) in which the letter was written, with levels "P1", "P2", "P3, "P4", "P5"}
#'   \item{FIN_SYB}{Factor: whether the stem of the verb used with a third person singular ends in a sibilant, with levels "no", "yes"}
#'   \item{FOL_FRIC}{Factor: what the word after the verb used with a third person singular begins with, with levels "other", "s", "th"}
#'   \item{GRAM}{Factor: whether the verb used with a third person singular is a grammatical verb (rather than a lexical one), with levels "no", "yes"}
#' }
#'
#' @details This is part of the data set used in Gries, Stefan Th. & Martin Hilpert. 2010. Modeling diachronic change in the third person singular: [...]. *English Language and Linguistics* 14(3). 293-320.
#' @source see Gries & Hilpert (2010)
#' @references \url{https://www.stgries.info/research/2010_STG-MH_3rdPersonSg_EnglLangLing.pdf}
read.delim("thirdpers.csv", stringsAsFactors=TRUE)
