#' @title To vs. ing priming
#' @name toingpriming
#' @description This data set is concerned with the *to*-/*-ing* alternation in English, i.e. the question is whether a speaker says *I like to swim* or *I like swimming*. Native speakers of English were presented two sentences in an experiment, a prime/context sentence that already involved a *to*-/*-ing* alternation sentence and a target sentence involving another *to*-/*-ing* alternation sentence that the subjects were supposed to rate with regard to its acceptability on a 7-point scale from -3 to +3.
#' @docType data
#'
#' @format A data frame with 556 observations/cases and 5 variables:
#' \describe{
#'   \item{CASE}{Numeric: a unique identifier for each case, in the interval [1, 556]}
#'   \item{RATING}{Numeric: an ordinal acceptability judgment by a native speaker, in the interval [-3, 3] where a) -3 means 'completely unacceptable', b) 0 means 'intermediately (un)acceptable', c) 3 means 'perfectly acceptable'}
#'   \item{CXNOW}{Factor: what the rated target sentence was, with levels "ing", "to"}
#'   \item{VNOW_PREF`}{Factor: what the preference of the verb in the target sentence was, with levels "ing", "to"}
#'   \item{CXPREV}{Factor: what the prime sentence was, with levels "ing", "to"}
#' }
#'
#' @details This is part of the data set used in Gries, Stefan Th. & Stefanie Wulff. 2009. Psycholinguistic and corpus linguistic evidence for L2 constructions. *Annual Review of Cognitive Linguistics* 7. 163-186.
#' @source see Gries & Wulff (2009)
#' @references \url{https://www.stgries.info/research/2009_STG-SW_L2-ToIngComplementation_ARCL.pdf}
read.delim("toingpriming.csv", stringsAsFactors=TRUE)
