#' @title Word duration
#' @name wdurations
#' @description This data set contains word duration data for 6383 words and several potential predictors.
#' @docType data
#'
#' @format A data frame with 6383 observations/cases and 11 variables:
#' \describe
#'   \item{CASE}{Numeric: a unique identifier for each case, in the interval [1, 6383]}
#'   \item{CONV}{Factor: a unique identifier for each two-participant conversation, with 20 levels}
#'   \item{SPEAKER}{Factor: a unique identifier for each speaker, with 20 levels}
#'   \item{SEX}{Factor: the sex of the current turn’s speaker, with levels "female", "male"}
#'   \item{DURATION}{Numeric: the response variable, the duration of a word in ms, in the interval [14, 1405]}
#'   \item{POSINTURN}{Numeric: the main predictor of interest, the position of the word in the 10-word turn, in the interval [1, 10]}
#'   \item{LENGTH}{Numeric: the length of the word in phonemes, in the interval [1, 14]}
#'   \item{FREQ}{Numeric: an already transformed index of how frequent the word is in a reference corpus, in the interval [0, 18]}
#'   \item{SURPRISAL}{Numeric: how surprising the word is given the previous word, in the interval [0, 21]}
#'   \item{CLASS}{Factor: the 'class' of the word in each position, with levels "closed", "number", "open", "propname", "unclear"}
#'   \item{VOWELS}{Factor: whether the word in question contains one or more vowels, with levels "one", "two+"}
#' }
#'
#' @details This is a sample of the data set studied in Rühlemann & Gries (2020)
#' @source NA
#' @references \url{https://www.stgries.info/research/2020_CR-STG_TurnCompletion_JPhon.pdf}
read.delim("wdurations.csv", stringsAsFactors=TRUE)
